@@ -4,6 +4,8 @@ from scipy import stats
 import multiprocessing as mp
 from joblib import Parallel, delayed
 
+pd.options.mode.chained_assignment = None
+
 
 def unpack_woe(args):
     return woe_binning(*args)
@@ -11,8 +13,8 @@ def unpack_woe(args):
 
 def merge_bins(df, bins_index):
     bins_index.sort()
-    interval_start_include = df.loc[bins_index[0]].interval_start_include
-    interval_end_exclude = df.loc[bins_index[-1]].interval_end_exclude
+    interval_start_include = df.loc[bins_index[0], 'interval_start_include']
+    interval_end_exclude = df.loc[bins_index[-1], 'interval_end_exclude']
     df_indexed = df[bins_index[0]: bins_index[-1] + 1]
     size = df_indexed['size'].sum()
     bads = df_indexed.bads.sum()
@@ -196,7 +198,7 @@ def woe_binning(target, dataset, n_threshold, n_occurences=1, p_threshold=0.1, s
                 summary["mean"] * summary["size"] < n_occurences) | (
                             summary["next_mean"] * summary["next_size"] < n_occurences)
 
-        summary[condition].p_value = summary[condition].p_value + 1
+        summary.loc[condition, 'p_value'] = summary.loc[condition, 'p_value'] + 1
 
         summary["p_value"] = summary.apply(
             lambda row: row["p_value"] + 1 if (row["size"] < n_threshold) | (row["next_size"] < n_threshold) |
@@ -223,8 +225,8 @@ def woe_binning(target, dataset, n_threshold, n_occurences=1, p_threshold=0.1, s
 
     woe_summary = summary[[column, "size", "mean"]]
     woe_summary.columns = ["interval_start_include", "size", "mean"]
-    woe_summary["interval_end_exclude"] = woe_summary.interval_start_include.shift(-1).fillna(interval_end)
-    woe_summary.interval_start_include.loc[0] = interval_end * -1
+    woe_summary["interval_end_exclude"] = woe_summary.interval_start_include.shift(-1).fillna(interval_end).to_list()
+    woe_summary['interval_start_include'] = interval_end * -1
     woe_summary["variable"] = column
     woe_summary = woe_summary[["variable", "interval_start_include", "interval_end_exclude", "size", "mean"]]
 
